==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>O Imagem é uma ferramenta de visualização de imagens com interface fashion e desempenho suave.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Este arquivo contém várias páginas, use Evince para ver todas as páginas.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Abrir Diretório</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>O usuário não tem permissão para visualizar a imagem</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimensão</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data da captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distância focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medição</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanço de branco</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo da lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de cor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da câmera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Nenhuma escala</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Ajustar página a imagem</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Ajustar imagem a página</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escalar para:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetros</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetros</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Polegadas</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posição da Imagem</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Configurações da Imagem</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Configurações da Imagem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persianas</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Alternador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Deslizamento</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Circulo</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd/MM/yyyy HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Digite um novo nome</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Selecionar Diretório</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Este diretório está desativado para sincronização</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Adicionar pasta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Gerenciamento de Diretório Sincronizado</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>A lista do diretório está vazia</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancelar sincronização</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>O dispositivo foi removido</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Este diretório não existe</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculando...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualizando Imagem</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Fim da apresentação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotacionar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotacionar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Tela anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Próxima tela</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair da Tela Cheia</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Aumentar zoom</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Reduzir zoom</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Visualizar Imagem</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restaurar Padrões</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Fim da apresentação</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotacionar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotacionar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Configurações de Slide</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Efeito de transição</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Duração da transição</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segundo</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Escala 1:1 </translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar na janela</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Gerenciamento de imagem</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Escala 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar à janela</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Configurações de Slide</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efeito</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Linha do tempo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Adicionar ao novo álbum</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair da Tela Cheia</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Exibir janela de navegação</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar janela de navegação</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotacionar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotacionar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imagens</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Desenho</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.16.orig.tar.xz: deepin-image-viewer-5.9.16/src/translations/deepin-image-viewer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Nenhuma imagem encontrada</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualizando Imagem</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair da Tela Cheia</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Aumentar zoom</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Reduzir zoom</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>O Imagem é uma ferramenta de visualização de imagens com interface fashion e desempenho suave.</translation>
    </message>
</context>
</TS>
